django-ttag — django-ttag v1.0-alpha documentation

### Navigation

- index
- next |
- django-ttag v1.0-alpha documentation »

# django-ttag

This documentation covers the 1.0 release of django-ttag, a template tag constructor library for Django created for the purpose of making writing template tags easier.

The tag syntax is modelled on Django’s friendly syntaxes for models and forms.

To get up and running, consult the installation guide which describes all the necessary steps to install and configure this application.

- Installation
  - Installing django-ttag
  - Configuring your project
- TTag reference
  - Overview
  - Tag
  - Arguments
  - Argument Types
  - Full Example
- TTag reference
  - Overview
  - Example
  - Defining arguments
  - Altering context
  - Writing a block tag

### Navigation

- index
- next |
- django-ttag v1.0-alpha documentation »